@@ -419,15 +419,64 @@ class Connections(WMLResource):
         """
         if not self._client.ICP:
             raise WMLClientError('Not supported on this environment.')
-        
-        response = requests.get(
-            self._client.service_instance._href_definitions.get_wsd_model_attachment_href() + 'dbdrivers',
-            headers=self._client._get_headers(no_content_type=True),
-            params=self._client._params(),
-            verify=not self._client.ICP
-        )
-        jars = [[el['path'].split('/')[-1]] for el in response.json()['resources']]
 
+        try:
+            self._list_uploaded_db_drivers_new_api()
+        except:
+            response = requests.get(
+                self._client.service_instance._href_definitions.get_wsd_model_attachment_href() + 'dbdrivers',
+                headers=self._client._get_headers(no_content_type=True),
+                params=self._client._params()
+            )
+            jars = [[el['path'].split('/')[-1]] for el in response.json()['resources']]
+
+            self._list(jars, [u'NAME'], None, None)
+
+    @docstring_parameter({'str_type': STR_TYPE_NAME})
+    def get_uploaded_db_drivers(self): # TODO not yet documented
+        # """
+        #    Get uploaded db driver jar names and paths.
+        #    Supported for IBM Cloud Pak for Data, version 4.6.1 and above.
+        #
+        #    **Output**
+        #
+        #    .. important::
+        #         Returns dictionary containing name and path for connection files.\n
+        #         **return type**: Dict[Str, Str]\n
+        #
+        #    **Example**
+        #
+        #     >>> result = client.connections.get_uploaded_db_drivers()
+        #
+        # """
+        if not self._client.ICP:
+            raise WMLClientError('Not supported on this environment.')
+
+        response = requests.get(
+            self._client.service_instance._href_definitions.get_connections_files_href(),
+            headers=self._client._get_headers(no_content_type=True)
+        )
+        result = self._handle_response(200, u'get uploaded db drivers', response)['resources']
+        return dict([(el['fileName'], el['url']) for el in result])
+
+    @docstring_parameter({'str_type': STR_TYPE_NAME})
+    def _list_uploaded_db_drivers_new_api(self):
+        """
+           List uploaded db driver jars.
+           Supported for IBM Cloud Pak for Data only.
+
+           **Output**
+
+           .. important::
+                This method only prints the uploaded db driver jar names.\n
+                **return type**: Str\n
+
+           **Example**
+
+            >>> client.connections._list_uploaded_db_drivers_new_api()
+
+        """
+        jars = [[name] for name in self.get_uploaded_db_drivers()]
         self._list(jars, [u'NAME'], None, None)
 
     @docstring_parameter({'str_type': STR_TYPE_NAME})
@@ -491,19 +540,84 @@ class Connections(WMLResource):
         if not self._client.ICP:
             raise WMLClientError('Not supported on this environment.')
 
+        try:
+            self._upload_db_driver_new_api(path)
+        except:
+            driver_file_name = path.split('/')[-1]
+
+            with open(path, 'rb') as fdata:
+                content_upload_url = self._client.service_instance._href_definitions.get_wsd_model_attachment_href() + \
+                                     "dbdrivers/" + quote(driver_file_name, safe='')
+                response = requests.put(
+                    content_upload_url,
+                    files={'file': ('native', fdata, 'application/octet-stream', {'Expires': '0'})},
+                    headers=self._client._get_headers(no_content_type=True),
+                    params=self._client._params()
+                )
+
+                self._client.repository._handle_response(201, 'uploading db driver jar', response)
+
+    @docstring_parameter({'str_type': STR_TYPE_NAME})
+    def _upload_db_driver_new_api(self, path: str):
+        """
+           Upload db driver jar.
+           Supported for IBM Cloud Pak for Data only, version 4.6.1 and above.
+
+           **Parameters**
+
+           .. important::
+                #. **path**:  path to db driver jar\n
+                   **type**: str\n
+
+           **Example**
+
+            >>> client.connections._upload_db_driver_new_api('example/path/db2jcc4.jar')
+
+        """
+        if not self._client.ICP:
+            raise WMLClientError('Not supported on this environment.')
+
         driver_file_name = path.split('/')[-1]
 
         with open(path, 'rb') as fdata:
-            content_upload_url = self._client.service_instance._href_definitions.get_wsd_model_attachment_href() + \
-                                 "dbdrivers/" + quote(driver_file_name, safe='')
-            response = requests.put(
+            content_upload_url = self._client.service_instance._href_definitions.get_connections_file_href(quote(driver_file_name, safe=''))
+            response = requests.post(
                 content_upload_url,
-                files={'file': ('native', fdata, 'application/octet-stream', {'Expires': '0'})},
-                headers=self._client._get_headers(no_content_type=True),
-                params=self._client._params()
+                data=fdata,
+                headers=self._client._get_headers(content_type='application/octet-stream')
             )
 
-            self._client.repository._handle_response(201, 'uploading db driver jar', response)
+            if response.status_code == 403:
+                raise WMLClientError("User is missing [configure_platform] permission to upload new jar file.")
+
+            self._client.repository._handle_response(200, 'uploading db driver jar', response, json_response=False)
+
+    @docstring_parameter({'str_type': STR_TYPE_NAME})
+    def get_db_driver_url(self, name: str): # TODO not document yet
+        # """
+        #    Get signed db driver jar url to be used during creating of JDBC generic connection. The jar name passed as argument needs to be uploaded into system first.
+        #    Supported for IBM Cloud Pak for Data only, version 4.6.1 and above..
+        #
+        #    **Parameters**
+        #
+        #    .. important::
+        #         #. **jar_name**:  db driver jar name\n
+        #            **type**: str\n
+        #
+        #    **Example**
+        #
+        #     >>> client.connections.get_db_driver_url('db2jcc4.jar')
+        #
+        # """
+        if not self._client.ICP:
+            raise WMLClientError('Not supported on this environment.')
+
+        try:
+            return self.get_uploaded_db_drivers()[name]
+        except WMLClientError as e:
+            raise e
+        except:
+            raise WMLClientError(f"Driver jar with name {name} not found.")
 
     @docstring_parameter({'str_type': STR_TYPE_NAME})
     def sign_db_driver_url(self, jar_name: str):
@@ -522,24 +636,30 @@ class Connections(WMLResource):
             >>> client.connections.sign_db_driver_url('db2jcc4.jar')
 
         """
-        if not self._client.ICP:
-            raise WMLClientError('Not supported on this environment.')
+        try:
+            #if self._client.ICP_46:
+            #    print("Warning: This function is deprecated. Use `get_db_driver_url(name)` instead.")
+            res = self.get_db_driver_url(jar_name)
+            return res
+        except:
+            if not self._client.ICP:
+                raise WMLClientError('Not supported on this environment.')
 
-        signed_url = self._client.service_instance._href_definitions.get_wsd_model_attachment_href() + \
-                     quote("dbdrivers/" + jar_name, safe='') + "/signed"
-        params = self._client._params()
+            signed_url = self._client.service_instance._href_definitions.get_wsd_model_attachment_href() + \
+                         quote("dbdrivers/" + jar_name, safe='') + "/signed"
+            params = self._client._params()
 
-        params['expires_in'] = 5000
+            params['expires_in'] = 5000
 
-        response = requests.post(
-            signed_url,
-            headers=self._client._get_headers(no_content_type=True),
-            params=params
-        )
+            response = requests.post(
+                signed_url,
+                headers=self._client._get_headers(no_content_type=True),
+                params=params
+            )
 
-        self._client.repository._handle_response(201, 'signing db driver url', response, json_response=False)
+            self._client.repository._handle_response(201, 'signing db driver url', response, json_response=False)
 
-        return unquote(response.headers['Location'])
+            return unquote(response.headers['Location'])
 
     @staticmethod
     def requests_retry_session(retries=3, backoff_factor=0.3, status_forcelist=(500, 502, 503, 504, 521, 524), session=None):
