@@ -166,7 +166,7 @@ class AutoAI(BaseExperiment):
                   desc: str = None,
                   test_size: float = None, # deprecated
                   holdout_size: float = 0.1,
-                  max_number_of_estimators: int = 2,
+                  max_number_of_estimators: int = None,
                   train_sample_rows_test_size: float = None,
                   include_only_estimators: List[Union['ClassificationAlgorithms', 'RegressionAlgorithms',
                                                       'ForecastingAlgorithms']] = None,
@@ -244,8 +244,8 @@ class AutoAI(BaseExperiment):
         max_number_of_estimators: int, optional
             Maximum number (top-K ranked by DAUB model selection) of the selected algorithm, or estimator types,
             for example LGBMClassifierEstimator, XGBoostClassifierEstimator, or LogisticRegressionEstimator
-            to use in pipeline composition.  The default is 2, where only the highest ranked by model
-            selection algorithm type is used. (min 1, max 4)
+            to use in pipeline composition. The default is None that means the true default value will be determined by
+            the internal different algorithms, where only the highest ranked by model selection algorithm type is used.
 
         train_sample_rows_test_size: float, optional
             Training data sampling percentage
