@@ -80,8 +80,8 @@ class RemoteAutoPipelines(BaseAutoPipelines):
     max_num_daub_ensembles: int, optional
         Maximum number (top-K ranked by DAUB model selection) of the selected algorithm, or estimator types,
         for example LGBMClassifierEstimator, XGBoostClassifierEstimator, or LogisticRegressionEstimator
-        to use in pipeline composition.  The default is 1, where only the highest ranked by model
-        selection algorithm type is used.
+        to use in pipeline composition. The default is None that means the true default value will be determined by the
+        internal different algorithms, where only the highest ranked by model selection algorithm type is used.
 
     train_sample_rows_test_size: float, optional
         Training data sampling percentage
@@ -131,7 +131,7 @@ class RemoteAutoPipelines(BaseAutoPipelines):
                  scoring: 'Metrics' = None,
                  desc: str = None,
                  holdout_size: float = 0.1,
-                 max_num_daub_ensembles: int = 1,
+                 max_num_daub_ensembles: int = None,
                  t_shirt_size: 'TShirtSize' = TShirtSize.M,
                  train_sample_rows_test_size: float = None,
                  include_only_estimators: List[Union['ClassificationAlgorithms', 'RegressionAlgorithms']] = None,
