@@ -910,7 +910,7 @@ class DataConnection(BaseDataConnection):
         # create data statistics if data were not downloaded with flight:
         if not isinstance(data, tuple) and _return_subsampling_stats:
             data = (data, {"data_batch_size": sys.getsizeof(data),
-                           "data_batch_no_rows": len(data)})
+                           "data_batch_nrows": len(data)})
 
         if binary:
             return data
