@@ -29,6 +29,7 @@ is_lib_installed(lib_name='pyarrow', install=True)
 import pyarrow as pa
 from pyarrow import flight
 from warnings import warn
+from math import ceil
 
 
 logger = logging.getLogger("automl")
@@ -532,8 +533,12 @@ class FlightConnection:
         if len(data) == 1:
             row_size = sys.getsizeof(data.iloc[0].values)
 
-        else:
-            row_size = sys.getsizeof(data.iloc[:2]) - sys.getsizeof(data.iloc[:1])
+        elif len(data)>1:
+            # Cast data to numerical types to reduce row size if possible. Needed especially when infer_schema is false
+            processed_data = self._cast_columns_to_float_64(data)
+            row_size = sys.getsizeof(processed_data) // len(processed_data)
+        else:  # len(data) == 0
+            row_size = 0
 
         if self.row_size == 0:
             self.row_size = row_size
@@ -663,7 +668,7 @@ class FlightConnection:
                                   "data_nrows": self.downloaded_data_nrows,
                                   "data_batch_size": sys.getsizeof(data),
                                   "data_batch_nrows": len(data),
-                                  "no_batches": self.downloaded_data_nrows // len(data)}
+                                  "no_batches": ceil(self.downloaded_data_nrows / len(data))}
                     yield data, data_stats
                 else:
                     yield data
@@ -833,7 +838,7 @@ class FlightConnection:
                             if max_rows_total < self.total_nrows_limit:
                                 self.total_nrows_limit = max_rows_total
                         else:
-                            self.total_size_limit = max_rows_total
+                            self.total_nrows_limit = max_rows_total
 
                     if self.total_nrows_limit and self.total_nrows_limit < max_rows:
                         return self.total_nrows_limit
@@ -1057,11 +1062,13 @@ class FlightConnection:
         if self.extra_interaction_properties is not None:
             command["interaction_properties"].update(self.extra_interaction_properties)
 
-        command.update(self.flight_parameters)
-
-        if self.number_of_batch_rows is not None:
+        # note: if number_of_batch_rows is bigger that 10 000 then set the 10 000 as batch_size in command. #
+        # to specify bigger batch_size use flight_parameters parameter - Flight limitation is 100 000(but sometimes it's to much).
+        if self.number_of_batch_rows is not None and self.number_of_batch_rows < default_batch_size:
             command['batch_size'] = self.number_of_batch_rows
 
+        command.update(self.flight_parameters)
+
         if self.space_id is not None:
             command['space_id'] = self.space_id
 
