@@ -97,8 +97,12 @@ class HybridArtifactLoader(object):
     def _content_reader_gzip(self):
         if self._download_href is not None:
             if self._download_href.__contains__("models"):
-                download_url = self._download_href + f"&space_id={self.meta.prop('space_id')}"\
-                                                     "&content_format=pipeline-node&pipeline_node_id=automl"
+                if self.meta.prop('space_id'):
+                    download_url = self._download_href + f"&space_id={self.meta.prop('space_id')}"\
+                                                         "&content_format=pipeline-node&pipeline_node_id=automl"
+                elif self.meta.prop('project_id'):
+                    download_url = self._download_href + f"&project_id={self.meta.prop('project_id')}" \
+                                                         "&content_format=pipeline-node&pipeline_node_id=automl"
                 return self.client.repository_api.download_artifact_content_v4_cloud(download_url, 'true')
 
     def _content_reader_json(self):
