@@ -18,6 +18,7 @@ from ibm_watson_machine_learning.helpers.connections import (
     DataConnection, S3Location, FSLocation, AssetLocation, CP4DAssetLocation, WMLSAssetLocation, CloudAssetLocation,
     WSDAssetLocation, DeploymentOutputAssetLocation, ContainerLocation, S3Connection)
 from ibm_watson_machine_learning.utils.autoai.enums import (DataConnectionTypes)
+from ibm_watson_machine_learning.utils.autoai.errors import ContainerTypeNotSupported
 
 if TYPE_CHECKING:
     from ibm_watson_machine_learning.workspace import WorkSpace
@@ -44,6 +45,7 @@ def validate_source_data_connections(source_data_connections: List['DataConnecti
                 data_connection.location = AssetLocation(asset_id)
                 data_connection.type = DataConnectionTypes.DS
             # --- end note
+
         elif isinstance(data_connection.location, WSDAssetLocation):
             # note: try to move local asset to server
             data_connection.location._move_asset_to_server(workspace=workspace)
@@ -52,13 +54,15 @@ def validate_source_data_connections(source_data_connections: List['DataConnecti
             # note: try to move local asset to server
             data_connection.location._wsd_move_asset_to_server(workspace=workspace)
             # --- end note
-        elif isinstance(data_connection.connection, S3Connection) and isinstance(data_connection.location,
-                                                                                 ContainerLocation):
-            # note: remove S3 inline credential from data asset before training
-            data_connection.connection = None
-            if hasattr(data_connection.location, 'bucket'):
-                delattr(data_connection.location, 'bucket')
-            # --- end note
+        elif isinstance(data_connection.location, ContainerLocation):
+            if workspace.wml_client.ICP:
+                raise ContainerTypeNotSupported() # block Container type on CPD
+            elif isinstance(data_connection.connection, S3Connection):
+                # note: remove S3 inline credential from data asset before training
+                data_connection.connection = None
+                if hasattr(data_connection.location, 'bucket'):
+                    delattr(data_connection.location, 'bucket')
+                # --- end note
 
         elif isinstance(data_connection.connection, S3Connection) and isinstance(data_connection.location,
                                                                                  AssetLocation):
