@@ -42,7 +42,7 @@ def is_run_id_exists(wml_credentials: Dict, run_id: str, space_id: Optional[str]
         client.set.default_space(space_id)
 
     try:
-        client.training.get_details(run_id)
+        client.training.get_details(run_id, _internal=True)
 
     except ApiRequestFailure as e:
         if 'Status code: 404' in str(e):
