@@ -638,11 +638,7 @@ def is_lib_installed(lib_name: str, minimum_version: Optional[str] = None, insta
         installed = False
 
     if installed:
-        try:
-            installed_module_version = fallback_to_pip_for_version_check(lib_name=lib_name)
-
-        except Exception:
-            installed_module_version = pkg_resources.get_distribution(lib_name).version
+        installed_module_version = get_module_version(lib_name)
 
         if minimum_version is not None:
             if version.parse(installed_module_version) < version.parse(minimum_version):
@@ -682,26 +678,13 @@ def install_library(lib_name: str, version: Optional[str] = None, strict: Option
         raise CannotInstallLibrary(lib_name=lib_name, reason=str(e))
 
 
-def fallback_to_pip_for_version_check(lib_name: str) -> str:
+def get_module_version(lib_name: str) -> str:
     """Use only when you need to check package version by package name with pip."""
+    from importlib.metadata import version
     try:
-        from pip._internal.utils.misc import get_installed_distributions
-        packages = get_installed_distributions()
-        installed_module_version = None
-
-        for pkg in packages:
-            if pkg.key == lib_name:
-                installed_module_version = pkg._version
-                break
-
-        if installed_module_version is None:
-            raise pkg_resources.DistributionNotFound()
-
-        else:
-            return installed_module_version
-
-    except Exception:
-        raise pkg_resources.DistributionNotFound()
+        return version(lib_name)
+    except:
+        return pkg_resources.get_distribution(lib_name).version
 
 
 def prepare_interaction_props_for_cos(source_params: dict, file_name: str) -> dict:
